# Generated by Django 4.2.13 on 2024-07-11 10:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djangoldp_dashboard", "0008_alter_dashboard_options_alter_dashboard_urlid"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dashboard",
            name="size",
            field=models.CharField(
                choices=[
                    ("1", "1"),
                    ("12", "1/2"),
                    ("13", "1/3"),
                    ("14", "1/4"),
                    ("23", "2/3"),
                    ("24", "2/4"),
                    ("34", "3/4"),
                ],
                default="1",
                max_length=2,
            ),
        ),
    ]



# Generated by Django 4.2.13 on 2024-07-01 10:55

from django.db import migrations
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ("djangoldp_dashboard", "0007_auto_20210223_2254"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="dashboard",
            options={
                "default_permissions": {"control", "add", "delete", "change", "view"}
            },
        ),
        migrations.AlterField(
            model_name="dashboard",
            name="urlid",
            field=djangoldp.fields.LDPUrlField(
                blank=True, db_index=True, null=True, unique=True
            ),
        ),
    ]



from django.db import models
from django.db.models import F, Max
from django.utils.translation import gettext_lazy as _
from djangoldp.models import Model
from djangoldp.permissions import ReadOnly

SIZE_CHOICES = [
    ('1', '1'),
    ('12', '1/2'),
    ('13', '1/3'),
    ('14', '1/4'),
    ('23', '2/3'),
    ('24', '2/4'),
    ('34', '3/4')
]

class Dashboard(Model):
    target = models.CharField(max_length=20, default='default')
    order = models.IntegerField(blank=True, null=True)
    size = models.CharField(max_length=2, choices=SIZE_CHOICES, default='1')
    background = models.BooleanField(default=True)
    content = models.TextField()

    def save(self, *args, **kwargs):
        if self.pk is None:
            if self.order is None:
                max_order = Dashboard.objects.filter(target=self.target).aggregate(Max('order'))['order__max']
                self.order = (max_order + 1) if max_order is not None else 1
            else:
                Dashboard.objects.filter(target=self.target, order__gte=self.order).update(order=F('order') + 1)
        else:
            old_order = Dashboard.objects.get(pk=self.pk).order
            if self.order is None:
                max_order = Dashboard.objects.filter(target=self.target).aggregate(Max('order'))['order__max']
                self.order = (max_order + 1) if max_order is not None else 1
            if old_order is not None and self.order is not None and self.order != old_order:
                if self.order > old_order:
                    Dashboard.objects.filter(target=self.target, order__gt=old_order, order__lte=self.order).update(order=F('order') - 1)
                else:
                    Dashboard.objects.filter(target=self.target, order__lt=old_order, order__gte=self.order).update(order=F('order') + 1)

        super(Dashboard, self).save(*args, **kwargs)

    class Meta(Model.Meta):
        verbose_name = _("Dashboard")
        verbose_name_plural = _("Dashboards")
        ordering = ["target"]
        serializer_fields = [
            "@id",
            "target",
            "order",
            "size",
            "background",
            "content",
        ]
        permission_classes = [ReadOnly]



# Generated by Django 4.2.13 on 2024-07-11 13:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("djangoldp_dashboard", "0009_alter_dashboard_size"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="dashboard",
            options={
                "default_permissions": {"add", "view", "delete", "control", "change"},
                "ordering": ["target"],
                "verbose_name": "Dashboard",
                "verbose_name_plural": "Dashboards",
            },
        ),
    ]



# Generated by Django 4.2.13 on 2024-07-11 13:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("djangoldp_dashboard", "0010_alter_dashboard_options"),
    ]

    operations = [
        migrations.AddField(
            model_name="dashboard",
            name="order",
            field=models.IntegerField(blank=True, null=True),
        ),
    ]



from django.contrib import admin
from djangoldp.admin import DjangoLDPAdmin
from djangoldp.models import Model

from .models import Dashboard


@admin.register(Dashboard)
class DashboardAdmin(DjangoLDPAdmin):
    list_display = ('urlid', 'target', 'order', 'size', 'background')
    exclude = ('urlid', 'is_backlink', 'allow_create_backlink')
    search_fields = ['urlid', 'target', 'order', 'size', 'background', 'content']
    ordering = ['urlid']

    def get_queryset(self, request):
        # Hide distant dashboard cards
        queryset = super(DashboardAdmin, self).get_queryset(request)
        internal_ids = [x.pk for x in queryset if not Model.is_external(x)]
        return queryset.filter(pk__in=internal_ids)
